# modusa

[**modusa**](https://meluron-toolbox.github.io/modusa/) is a library with utility tools especially for audio signals.

---

## Installation

> modusa is under active development. You can install the latest version via:

```
pip install modusa
```

---

## Tests

```
pytest tests/
```

---

## Status

modusa is in **early alpha**. Expect rapid iteration, breaking changes, and big ideas.  
If you like the direction, consider ⭐ starring the repo and opening issues or ideas.

---

## Few useful command

To push doc changes
```
ghp-import -n -p -f docs/build/html
```

To create a dist
```
pdm build
```

To upload on pypi
```
twine upload dist/*
```

## About

**modusa** is developed and maintained by [meluron](https://www.github.com/meluron),

---

## License

MIT License. See `LICENSE` for details.

---

## Contributions

Pull requests, ideas, and discussions are welcome!  
No matter which domain you are in, if you work with any signal, we'd love your input.
